summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/gpssync/kmlexport.h
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/gpssync/kmlexport.h')
-rw-r--r--kipi-plugins/gpssync/kmlexport.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/kipi-plugins/gpssync/kmlexport.h b/kipi-plugins/gpssync/kmlexport.h
index 0dc32f2..2ef558d 100644
--- a/kipi-plugins/gpssync/kmlexport.h
+++ b/kipi-plugins/gpssync/kmlexport.h
@@ -23,17 +23,17 @@
#ifndef KIPIKMLEXPORTKMLEXPORT_H
#define KIPIKMLEXPORTKMLEXPORT_H
-// Qt includes.
+// TQt includes.
-#include <qcolor.h>
-#include <qdir.h>
-#include <qdom.h>
+#include <tqcolor.h>
+#include <tqdir.h>
+#include <tqdom.h>
// Local includes.
#include "kmlgpsdataparser.h"
-class QImage;
+class TQImage;
namespace KIPI
{
@@ -57,14 +57,14 @@ public:
kmlExport(KIPI::Interface* interface);
~kmlExport();
- bool createDir(QDir dir);
+ bool createDir(TQDir dir);
/*! generate the kml element for pictures with tumbnails
* @param interface the kipi interface
* @param KURL the URL of the picture
* @param kmlAlbum the album used
*/
- void generateImagesthumb(KIPI::Interface* interface, const KURL&, QDomElement &kmlAlbum);
+ void generateImagesthumb(KIPI::Interface* interface, const KURL&, TQDomElement &kmlAlbum);
/*! Produce a web-friendly file name
* otherwise, while google earth works fine, maps.google.com may not find pictures and thumbnail
@@ -72,14 +72,14 @@ public:
* @param the filename
* @return the webifyed filename
*/
- QString webifyFileName(const QString &fileName);
+ TQString webifyFileName(const TQString &fileName);
/*! Generate a square thumbnail from @fullImage of @size x @size pixels
* @param fullImage the original image
* @param size the size of the thumbnail
* @return the thumbnail
*/
- QImage generateSquareThumbnail(const QImage& fullImage, int size);
+ TQImage generateSquareThumbnail(const TQImage& fullImage, int size);
/*! Generate a square thumbnail from @fullImage of @size x @size pixels
* with a white border
@@ -87,8 +87,8 @@ public:
* @param size the size of the thumbnail
* @return the thumbnail
*/
- QImage generateBorderedThumbnail(const QImage& fullImage, int size);
- void addTrack(QDomElement &kmlAlbum);
+ TQImage generateBorderedThumbnail(const TQImage& fullImage, int size);
+ void addTrack(TQDomElement &kmlAlbum);
void generate();
int getConfig();
@@ -108,27 +108,27 @@ public:
int m_GPXAltitudeMode;
/** directory used in kmldocument structure */
- QString m_imageDir;
- QString m_GPXFile;
- QString m_UrlDestDir;
+ TQString m_imageDir;
+ TQString m_GPXFile;
+ TQString m_UrlDestDir;
/** temporary directory where everything will be created */
- QString m_tempDestDir;
+ TQString m_tempDestDir;
/** directory selected by user*/
- QString m_baseDestDir;
+ TQString m_baseDestDir;
- QString m_imgdir;
- QString m_KMLFileName;
+ TQString m_imgdir;
+ TQString m_KMLFileName;
- QColor m_GPXColor;
+ TQColor m_GPXColor;
KIPI::Interface *m_interface;
private:
- /*! the root document, used to create all QDomElements */
- QDomDocument *kmlDocument;
+ /*! the root document, used to create all TQDomElements */
+ TQDomDocument *kmlDocument;
/*! the GPS parsed data */
KMLGPSDataParser m_gpxParser;
@@ -137,54 +137,54 @@ private:
private:
- void logInfo(const QString& msg);
- void logError(const QString& msg);
- void logWarning(const QString& msg);
+ void logInfo(const TQString& msg);
+ void logError(const TQString& msg);
+ void logWarning(const TQString& msg);
/*!
* \fn KIPIKMLExport::kmlExport::addKmlElement(QDomElement target, QString tag)
* Add a new element
- * @param target the parent element to which add the element
+ * @param target the tqparent element to which add the element
* @param tag the new element name
* @return the New element
*/
- QDomElement addKmlElement(QDomElement &target, QString tag)
+ TQDomElement addKmlElement(TQDomElement &target, TQString tag)
{
- QDomElement kmlElement = kmlDocument->createElement( tag );
+ TQDomElement kmlElement = kmlDocument->createElement( tag );
target.appendChild( kmlElement );
return kmlElement;
}
/*!
* \fn KIPIKMLExport::kmlExport::addKmlTextElement(QDomElement target, QString tag, QString text)
* Add a new element with a text
- * @param target the parent element to which add the element
+ * @param target the tqparent element to which add the element
* @param tag the new element name
* @param text the text content of the new element
* @return the New element
*/
- QDomElement addKmlTextElement(QDomElement &target, QString tag, QString text)
+ TQDomElement addKmlTextElement(TQDomElement &target, TQString tag, TQString text)
{
- QDomElement kmlElement = kmlDocument->createElement( tag );
+ TQDomElement kmlElement = kmlDocument->createElement( tag );
target.appendChild( kmlElement );
- QDomText kmlTextElement = kmlDocument->createTextNode( text );
+ TQDomText kmlTextElement = kmlDocument->createTextNode( text );
kmlElement.appendChild( kmlTextElement );
return kmlElement;
}
/*!
* \fn KIPIKMLExport::kmlExport::addKmlHtmlElement(QDomElement target, QString tag, QString text)
* Add a new element with html content (html entities are escaped and text is wrapped in a CDATA section)
- * @param target the parent element to which add the element
+ * @param target the tqparent element to which add the element
* @param tag the new element name
* @param text the HTML content of the new element
* @return the New element
*/
- QDomElement addKmlHtmlElement(QDomElement &target, QString tag, QString text)
+ TQDomElement addKmlHtmlElement(TQDomElement &target, TQString tag, TQString text)
{
- QDomElement kmlElement = kmlDocument->createElement( tag );
+ TQDomElement kmlElement = kmlDocument->createElement( tag );
target.appendChild( kmlElement );
- QDomText kmlTextElement = kmlDocument->createCDATASection( text );
+ TQDomText kmlTextElement = kmlDocument->createCDATASection( text );
kmlElement.appendChild( kmlTextElement );
return kmlElement;
}
@@ -137,54 +137,54 @@ private:
/*!
- * \fn KIPIKMLExport::kmlExport::addKmlElement(QDomElement target, QString tag)
+ * \fn KIPIKMLExport::kmlExport::addKmlElement(TQDomElement target, TQString tag)
* Add a new element
@@ -137,54 +137,54 @@ private:
}
/*!
- * \fn KIPIKMLExport::kmlExport::addKmlTextElement(QDomElement target, QString tag, QString text)
+ * \fn KIPIKMLExport::kmlExport::addKmlTextElement(TQDomElement target, TQString tag, TQString text)
* Add a new element with a text
@@ -137,54 +137,54 @@ private:
}
/*!
- * \fn KIPIKMLExport::kmlExport::addKmlHtmlElement(QDomElement target, QString tag, QString text)
+ * \fn KIPIKMLExport::kmlExport::addKmlHtmlElement(TQDomElement target, TQString tag, TQString text)
* Add a new element with html content (html entities are escaped and text is wrapped in a CDATA section)